@@ -1,4 +1,4 @@
-#    Copyright (c) 2008-2009 Dominique Dumont.
+#    Copyright (c) 2008-2010 Dominique Dumont.
 #
 #    This library is free software; you can redistribute it and/or
 #    modify it under the terms of the GNU Lesser Public License as
@@ -22,7 +22,7 @@ use warnings;
 use Carp;
 use IO::File ;
 
-our $VERSION = '0.601';
+our $VERSION = '0.801';
 
 require XSLoader;
 XSLoader::load('Config::Augeas', $VERSION);
@@ -121,17 +121,18 @@ sub new {
     my $root  = delete $args{root} || '';
 
     my $save = delete $args{save} || '';
-    if    ($save eq 'backup')  { $flags ||= &AUG_SAVE_BACKUP }
-    elsif ($save eq 'newfile') { $flags ||= &AUG_SAVE_NEWFILE }
-    elsif ($save =~ 'noop')    { $flags ||= &AUG_SAVE_NOOP }
+    if    ($save eq 'backup')  { $flags |= &AUG_SAVE_BACKUP }
+    elsif ($save eq 'newfile') { $flags |= &AUG_SAVE_NEWFILE }
+    elsif ($save =~ 'noop')    { $flags |= &AUG_SAVE_NOOP }
     elsif ($save) { 
 	croak  __PACKAGE__," new: unexpected save value: $save. ",
 	  "Expected backup or newfile";
     }
 
-    $flags ||= &AUG_TYPE_CHECK if ( delete $args{type_check} || 0 );
-    $flags ||= &AUG_NO_STDINC  if ( delete $args{no_std_inc} || 0 ) ;
-    $flags ||= &AUG_NO_LOAD    if ( delete $args{no_load}    || 0 ) ;
+    $flags |= &AUG_TYPE_CHECK  if ( delete $args{type_check}  || 0 );
+    $flags |= &AUG_NO_STDINC   if ( delete $args{no_std_inc}  || 0 ) ;
+    $flags |= &AUG_NO_LOAD     if ( delete $args{no_load}     || 0 ) ;
+    $flags |= &AUG_ENABLE_SPAN if ( delete $args{enable_span} || 0 ) ;
 
     croak  __PACKAGE__," new: unexpected parameters: ",
       join (' ',keys %args) 
@@ -337,6 +338,22 @@ sub move {
     return $result == 0 ? 1 : 0 ;
 }
 
+
+=head2 span ( path )
+
+Returns a hash containing the filename, label_start, label_end,
+value_start, value_end, span_start and span_end of the given C<path>.
+
+=cut
+
+sub span {
+    my $self = shift ;
+    my $path = shift || croak __PACKAGE__," span: undefined path";
+
+    return $self->{aug_c} -> span($path) ;
+
+}
+
 =head2 match ( pattern )
 
 Returns an array of the elements that match of the path expression
@@ -477,11 +494,13 @@ sub print {
 =head2 error
 
 Returns the error code from the last API call as a short string:
-noerror, nomem, internal, pathx, nomatch, manymatch, syntax
+noerror, nomem, internal, pathx, nomatch, manymatch, syntax, nolens,
+multiple_transforms
 
 =cut
 
-my @errcode = qw/noerror nomem internal pathx nomatch manymatch syntax/;
+my @errcode = qw/noerror nomem internal pathx nomatch manymatch syntax nolens 
+		multiple_transforms/;
 
 sub error {
     my $self   = shift ;
@@ -561,7 +580,7 @@ Dominique Dumont, E<lt>ddumont at cpan dot org@<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008 by Dominique Dumont
+Copyright (C) 2008-2010 by Dominique Dumont
 
 This library is free software; you can redistribute it and/or modify
 it under the LGPL terms.
